@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Local User Autoresponder and Mail Forwarder Plugin
-  * Copyright (c) 2004-2009 Jonathan Bayer <jbayer@spamcop.net>,
+  * Copyright (c) 2004-2007 Jonathan Bayer <jbayer@spamcop.net>,
   *                         Paul Lesniewski <paul@squirrelmail.org>,
   *                         Dan Astoorian 
   * Licensed under the GNU GPL. For full terms see the file COPYING.
@@ -108,7 +108,7 @@ if (do_action('list', $laf_prefs_file))
 
    foreach ($vac_prefs as $a_pref) 
    {
-      if (!empty($a_pref) && strpos($a_pref, '#') !== 0 && strpos($a_pref, '=') > 0) 
+      if (!empty($a_pref) && strpos($a_pref, '#') !== 0) 
       {
          list($pref_name, $pref_value) = explode('=', $a_pref, 2);
          $$pref_name = $pref_value;
@@ -584,7 +584,7 @@ if (strtolower($laf_backend) == 'ftp' && is_resource($FTP))
 
 
 sq_change_text_domain('squirrelmail');
-displayPageHeader($color, '');
+displayPageHeader($color, 'None');
 sq_change_text_domain('local_autorespond_forward');
 
 
@@ -685,7 +685,7 @@ function do_action($action, $remoteFile='', $localFile='', $list_err=FALSE)
 {
 
    global $username, $key, $onetimepad, $ftp_server, $laf_ldap_attribute,
-          $suid_binary, $vac_debug, $laf_backend, $laf_ftp_mode,
+          $suid_binary, $vac_debug, $laf_backend,
           $ftp_passive, $ldap_lookup_ftp_server, $laf_ldap_base, $laf_ldap_server,
           $use_ssl_ftp, $FTP, $www_initialize, $vl_errors, 
           $auth_user_localpart_only, $debug_suid_output_file;
@@ -802,14 +802,6 @@ function do_action($action, $remoteFile='', $localFile='', $list_err=FALSE)
    if ($laf_backend == 'ftp')
    {
 
-      // set transfer mode
-      //
-      if ($laf_ftp_mode)
-         $ftp_mode = FTP_BINARY;
-      else
-         $ftp_mode = FTP_ASCII;
-
-
       // use FTP over SSL?
       //
       if ($use_ssl_ftp) $ftp_conn_func = 'ftp_ssl_connect';
@@ -910,7 +902,7 @@ function do_action($action, $remoteFile='', $localFile='', $list_err=FALSE)
 
          if ($laf_backend == 'ftp')
          {
-            if (ftp_put($FTP, $remoteFile, $localFile, $ftp_mode))
+            if (ftp_put($FTP, $remoteFile, $localFile, FTP_ASCII))
                $result = TRUE;
             else 
             {
@@ -959,7 +951,7 @@ function do_action($action, $remoteFile='', $localFile='', $list_err=FALSE)
 
          if ($laf_backend == 'ftp')
          {
-            if (ftp_get($FTP, $localFile, $remoteFile, $ftp_mode))
+            if (ftp_get($FTP, $localFile, $remoteFile, FTP_ASCII))
                $result = TRUE;
             else 
             {
